@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_codebuild._jsii
 import aws_cdk.aws_codecommit._jsii
@@ -19,9 +19,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-pull-request-check",
-    "1.1.10",
+    "1.1.11",
     __name__[0:-6],
-    "cdk-pull-request-check@1.1.10.jsii.tgz",
+    "cdk-pull-request-check@1.1.11.jsii.tgz",
 )
 
 __all__ = [
